@@ -30,7 +30,7 @@ use namespace::clean;
 
 with 'Lintian::Check';
 
-sub binary {
+sub installable {
     my ($self) = @_;
 
     my $pkg = $self->package;
