@@ -60,7 +60,7 @@ sub source {
     my $processable = $self->processable;
     my $group = $self->group;
 
-    my $debian_dir = $processable->index_resolved_path('debian/');
+    my $debian_dir = $processable->patched->resolve_path('debian/');
     my $dcontrol;
     $dcontrol = $debian_dir->child('control') if $debian_dir;
 
@@ -73,7 +73,7 @@ sub source {
     return if not $dcontrol->is_open_ok;
 
     # check that control is UTF-8 encoded
-    my $line = file_is_encoded_in_non_utf8($dcontrol->fs_path);
+    my $line = file_is_encoded_in_non_utf8($dcontrol->unpacked_path);
     if ($line) {
         $self->tag('debian-control-file-uses-obsolete-national-encoding',
             "at line $line");
@@ -81,7 +81,7 @@ sub source {
 
     # Nag about dh_make Vcs comment only once
     my $seen_vcs_comment = 0;
-    my $fd = $dcontrol->open;
+    open(my $fd, '<', $dcontrol->unpacked_path);
     while (<$fd>) {
         s/\s*\n$//;
 
@@ -134,7 +134,7 @@ sub source {
     eval {
         # check we can parse it, but ignore the result - we will fetch
         # the fields we need from $processable.
-        read_dpkg_control($dcontrol->fs_path);
+        read_dpkg_control($dcontrol->unpacked_path);
     };
     if ($@) {
         chomp $@;
@@ -338,33 +338,39 @@ sub source {
       and not $seen_main
       and $area eq 'main';
 
-    # Check for duplicate descriptions.
-    my (%seen_short, %seen_long);
-    for my $i (0 .. $#descriptions) {
-        my (@short, @long);
-        for my $j (($i + 1) .. $#descriptions) {
-            if ($descriptions[$i][1] eq $descriptions[$j][1]) {
-                my $package = $descriptions[$j][0];
-                push(@short, $package) unless $seen_short{$package};
-            }
-            next unless ($descriptions[$i][2] and $descriptions[$j][2]);
-            if ($descriptions[$i][2] eq $descriptions[$j][2]) {
-                my $package = $descriptions[$j][0];
-                push(@long, $package) unless $seen_long{$package};
-            }
+    my %short_descriptions;
+    my %long_descriptions;
+
+    for my $paragraph (@descriptions) {
+
+        my $package = @{$paragraph}[0];
+
+        my $short = @{$paragraph}[1];
+        if (length $short) {
+            $short_descriptions{$short} //= [];
+            push(@{$short_descriptions{$short}}, $package);
         }
-        if (@short) {
-            $self->tag('duplicate-short-description', $descriptions[$i][0],
-                @short);
-            for (@short) { $seen_short{$_} = 1 }
-        }
-        if (@long) {
-            $self->tag('duplicate-long-description', $descriptions[$i][0],
-                @long);
-            for (@long) { $seen_long{$_} = 1 }
+
+        my $long = @{$paragraph}[2];
+        if (length $long) {
+            $long_descriptions{$long} //= [];
+            push(@{$long_descriptions{$long}}, $package);
         }
     }
 
+    # check for duplicate short description
+    for my $short (keys %short_descriptions) {
+        $self->tag('duplicate-short-description',
+            @{$short_descriptions{$short}})
+          if scalar @{$short_descriptions{$short}} > 1;
+    }
+
+    # check for duplicate long description
+    for my $long (keys %long_descriptions) {
+        $self->tag('duplicate-long-description', @{$long_descriptions{$long}})
+          if scalar @{$long_descriptions{$long}} > 1;
+    }
+
     # check the syntax of the Build-Profiles field
     for my $bin (@package_names) {
         my $raw = $processable->binary_field($bin, 'build-profiles');
@@ -412,7 +418,7 @@ sub source {
     if (defined(my $r3 = $processable->source_field('rules-requires-root'))) {
         if ($r3 eq 'no') {
             $self->tag('rules-does-not-require-root');
-        } elsif ($r3 eq 'binary-targets') {
+        } else {
             $self->tag('rules-requires-root-explicitly');
         }
     } else {
@@ -423,7 +429,7 @@ sub source {
       BINARY:
         foreach my $proc ($group->get_binary_processables) {
             my $pkg = $proc->name;
-            foreach my $file ($proc->sorted_index) {
+            foreach my $file ($proc->installed->sorted_list) {
                 my $owner = $file->owner . ':' . $file->group;
                 next if $owner eq 'root:root';
                 $self->tag('should-specify-rules-requires-root',
