@@ -1,6 +1,7 @@
 # files/contents -- lintian check script -*- perl -*-
 
-# Copyright (C) 1998 Christian Schwarz and Richard Braakman
+# Copyright © 1998 Christian Schwarz and Richard Braakman
+# Copyright © 2020 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,7 +39,7 @@ has bin_binaries => (is => 'rwp', default => sub { [] });
 sub setup {
     my ($self) = @_;
 
-    for my $file ($self->info->sorted_index) {
+    for my $file ($self->processable->installed->sorted_list) {
 
         next
           unless $file->is_file;
@@ -64,21 +65,21 @@ sub get_checks_for_file {
     my %checks;
 
     return %checks
-      if $self->processable->pkg_src eq 'lintian';
+      if $self->processable->source eq 'lintian';
 
     $checks{'missing-depends-on-sensible-utils'}
       = '(?:select-editor|sensible-(?:browser|editor|pager))\b'
       if $file->name !~ m,^usr/share/(?:doc|locale)/,
-      and not $self->info->relation('all')->implies('sensible-utils')
-      and not $self->processable->pkg_src eq 'sensible-utils';
+      and not $self->processable->relation('all')->implies('sensible-utils')
+      and not $self->processable->source eq 'sensible-utils';
 
     $checks{'uses-dpkg-database-directly'} = '/var/lib/dpkg'
       if $file->name !~ m,^usr/share/(?:doc|locale)/,
       and $file->basename !~ m/^README(?:\..*)?$/
       and $file->basename !~ m/^changelog(?:\..*)?$/i
       and $file->basename !~ m/\.(?:html|txt)$/i
-      and $self->info->field('section', '') ne 'debian-installer'
-      and none { $_ eq $self->processable->pkg_src }
+      and $self->processable->field('section', '') ne 'debian-installer'
+      and none { $_ eq $self->processable->source }
     qw(base-files dpkg lintian);
 
     $checks{'file-references-package-build-path'}= quotemeta($self->build_path)
@@ -100,34 +101,60 @@ sub files {
 
     my %checks = $self->get_checks_for_file($file);
 
-    if (%checks) {
+    foreach my $tag (sort keys %checks) {
+        my $regex = $checks{$tag};
 
-        my $stringsfd = $self->info->strings($file);
-        my $strings = do { local $/; <$stringsfd> };
-        close($stringsfd)
-          or warn "Error closing strings fd: $!";
+        # prefer strings(1) output (eg. for ELF) if we have it
+        if (length $file->strings) {
+            $self->tag($tag, $file->name)
+              if $file->strings =~ m,^\Q$regex\E,m;
 
-        foreach my $tag (sort keys %checks) {
-            my $regex = $checks{$tag};
+        } else {
+            open(my $fd, '<:raw', $file->unpacked_path);
+            my $sfd = Lintian::SlidingWindow->new($fd);
+            while (my $block = $sfd->readwindow) {
+                next
+                  unless $block =~ $regex;
 
-            # prefer strings(1) output (eg. for ELF) if we have it
-            if ($strings) {
-                $self->tag($tag, $file->name)
-                  if $strings =~ m,^\Q$regex\E,m;
+                $self->tag($tag, $file->name);
+                last;
+            }
+            close($fd);
+        }
+    }
 
-            } else {
-                my $fd = $file->open(':raw');
-                my $sfd = Lintian::SlidingWindow->new($fd);
-                while (my $block = $sfd->readwindow) {
-                    next
-                      unless $block =~ $regex;
+    return;
+}
 
-                    $self->tag($tag, $file->name);
-                    last;
-                }
-                close($fd);
+sub installable {
+    my ($self) = @_;
+
+    # get maintainer scripts
+    my @control
+      = grep { $_->is_control } $self->processable->control->sorted_list;
+
+    for my $file (@control) {
+
+        next
+          unless $file->is_open_ok;
+
+        # why is lintian exempt from this check?
+        next
+          if $self->processable->source eq 'lintian';
+
+        my %checks = $self->get_checks_for_file($file);
+
+        return
+          unless %checks;
+
+        open(my $fd, '<', $file->unpacked_path);
+        while (<$fd>) {
+            for my $tag (keys %checks) {
+                $self->tag($tag, $file->name, "(line $.)")
+                  if $_ =~ $checks{$tag};
             }
         }
+        close $fd;
     }
 
     return;
